Cette classe represente le portfeuille financier cible de la compagnie d'assurance dans le cadre de
obligationest un objet de la classe Obligation representant le portfeuille cible obligation.
alloc_cibleest un objet data.frame indiquant l'allocation cible pour chaque produit.
Damien Tichit pour Sia Partners
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.