Cette classe represente le portfeuille passif de la compagnie d'assurance.
epargneest un objet de la classe Epargne representant le portfeuille epargne.
Damien Tichit pour Sia Partners
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.